@@ -1,6 +1,6 @@
 use 5.16.0;
 use warnings;
-package Games::Nintendo::Mario::NSMB 0.205;
+package Games::Nintendo::Mario::NSMB 0.207;
 
 use parent qw(Games::Nintendo::Mario);
 
@@ -84,16 +84,17 @@ Games::Nintendo::Mario::NSMB - a class for stylus-enabled Italian plumbers
 
 =head1 VERSION
 
-version 0.205
+version 0.207
 
 =head1 SYNOPSIS
 
   use Games::Nintendo::Mario::NSMB;
 
-  my $hero = new Games::Nintendo::Mario::SMB
-                   name  => 'Luigi',
-                   state => 'normal';
-  
+  my $hero = Games::Nintendo::Mario::SMB->new(
+   name  => 'Luigi',
+   state => 'normal',
+  );
+
   $hero->powerup('mushroom'); # doop doop doop!
   $hero->powerup('flower');   # change clothes
 
